/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.cli;

// for ROM manipulations
import java.io.PrintWriter;
import java.io.StringWriter;

// for CLI processing
import org.apache.commons.cli.HelpFormatter;
import org.apache.commons.cli.Options;

/**
 * CLI help maker.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: Help.java 630 2011-03-14 07:07:06Z yegor256@yahoo.com $
 */
public final class Help {

    /**
     * Response width.
     */
    public static final Integer WIDTH = 60;

    /**
     * Create help for options.
     * @param opts The options
     * @return The text
     * @throws Exception If something goes wrong
     * @todo #9 We need to get the name of BIN.jar from environment. Now
     *          it is statically programmed, which is not correct.
     */
    public String make(final Options opts) throws Exception {
        final HelpFormatter formatter = new HelpFormatter();
        formatter.setOptPrefix("--");
        final StringWriter writer = new StringWriter();
        formatter.printHelp(
            new PrintWriter(writer),
            this.WIDTH,
            "java -jar rempl-cli.jar",
            "REMPL " + new Version().get(),
            opts,
            2,
            2,
            "If you have any questions or suggestions please do not"
            + " hesitate to email us: team@rempl.com or submit them"
            + " online to our issue tracking system: http://trac.rempl.com/"
        );
        return writer.toString();
    }

}
