/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.cli.aether;

// collections
import java.util.ArrayList;
import java.util.Collection;

// AETHER
import org.sonatype.aether.collection.CollectRequest;
import org.sonatype.aether.graph.Dependency;
import org.sonatype.aether.graph.DependencyFilter;
import org.sonatype.aether.repository.RemoteRepository;
import org.sonatype.aether.resolution.DependencyRequest;
import org.sonatype.aether.util.artifact.DefaultArtifact;
import org.sonatype.aether.util.artifact.JavaScopes;
import org.sonatype.aether.util.filter.DependencyFilterUtils;

/**
 * Builder of dependency request.
 * @see Aether
 */
public final class RequestBuilder {

    /**
     * Instance of the builder.
     */
    public static final RequestBuilder INSTANCE = new RequestBuilder();

    /**
     * List of remote repositories.
     */
    private Collection<RemoteRepository> remotes =
        new ArrayList<RemoteRepository>();

    /**
     * Private ctor.
     */
    private RequestBuilder() {
        this.addRepository(
            "central",
            "http://repo1.maven.org/maven2/"
        );
    }

    /**
     * Add new remote repository.
     * @param name The unique name of the repository
     * @param url The URL of the repository
     */
    public void addRepository(final String name, final String url) {
        this.remotes.add(
            new RemoteRepository(name, "default", url)
        );
    }

    /**
     * Create dependency request.
     * @param artifact The artifact to find
     * @return The request
     * @see #resolve(String)
     */
    public DependencyRequest build(final String artifact) {
        final CollectRequest crq = new CollectRequest();
        crq.setRoot(
            new Dependency(
                new DefaultArtifact(artifact),
                JavaScopes.COMPILE
            )
        );
        for (RemoteRepository repo : this.remotes) {
            crq.addRepository(repo);
        }
        final DependencyFilter filter =
            DependencyFilterUtils.classpathFilter(JavaScopes.COMPILE);
        return new DependencyRequest(crq, filter);
    }


}
