/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.cli.aether;

// logging
import com.rempl.api.Logger;

// AETHER
import org.apache.maven.repository.internal.MavenRepositorySystemSession;
import org.sonatype.aether.RepositorySystem;
import org.sonatype.aether.RepositorySystemSession;
import org.sonatype.aether.repository.LocalRepository;

/**
 * Builder of SystemSession.
 * @see Aether
 */
public final class SessionBuilder {

    /**
     * Instance of the builder.
     */
    public static final SessionBuilder INSTANCE = new SessionBuilder();

    /**
     * Location of local repository.
     * @see #setLocation(String)
     */
    private String location;

    /**
     * Private ctor.
     */
    private SessionBuilder() {
        this.location = System.getProperty("user.home") + "/.m2/repository";
        if (Logger.isDebugEnabled(this)) {
            Logger.debug(
                this,
                "#SessionBuilder(): location=%s",
                this.location
            );
        }
    }

    /**
     * Set new location of the repository.
     * @param loc New location to set
     */
    public void setLocation(final String loc) {
        this.location = loc;
        if (Logger.isDebugEnabled(this)) {
            Logger.debug(
                this,
                "#setLocation(%s)",
                loc
            );
        }
    }

    /**
     * Create Aether session.
     * @param system The system to connect with
     * @return The session
     * @see Aether#resolve(String)
     */
    public RepositorySystemSession build(final RepositorySystem system) {
        final MavenRepositorySystemSession session =
            new MavenRepositorySystemSession();
        final LocalRepository local = new LocalRepository(this.location);
        session.setLocalRepositoryManager(
            system.newLocalRepositoryManager(local)
        );
        return session;
    }

}
